form

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Encode

func Encode(m map[string]string) []byte

Encode encodes the provided map[string]string as application/x-www-form-urlencoded form data. Each key and value in the map is URL-encoded and concatenated into a query string format. The resulting query string is returned as a byte slice, suitable for use as the body of a POST request.

Types

This section is empty.

Jump to