Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Encode ¶
Encode encodes the provided map[string]string as application/x-www-form-urlencoded form data. Each key and value in the map is URL-encoded and concatenated into a query string format. The resulting query string is returned as a byte slice, suitable for use as the body of a POST request.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.